function pyramid = RRgaussianPyramid(im, numLevels)
% pyramid = RRgaussianPyramid(im, numLevels)
%
% Computes a GaussianPyramid of image im, with numLevels levels.  
% Does not include the highest frequency level (the original image).  
% Returns a cell structure containing the levels of the pyramid.
%
% Reference: 
% Burt, P., & Adelson, E.H. The Laplacian Pyramid as a
% Compact Image Code. IEEE Trans. on Communication,
% COM-31:532-540, 1983.

% code by Ruth Rosenholtz

% The "gaussian" is a separable filter:
% G = [0.05, 0.25, 0.40, 0.25, 0.05].

pyramid = cell(numLevels, 1);
pyramid{1} = im;
for i=2:numLevels,
    if i==2,
        tmp = im;
    else
        tmp = pyramid{i-1};
    end
    pyramid{i} = reduce(tmp);   
    % This uses my old reduce program, which reflects the image about the
    % border before filtering, to minimize edge effects.
end
return;